from setuptools import setup

setup(name='distributions_ramon',
      version='0.11',
      description='Gaussian and Binomial distributions',
      packages=['distributions'],
      author = "RamonSantiago",
      author_email = "raysantiago1994@gmail.com",
      zip_safe=False)
